@@ -1,7 +1,10 @@
 from itertools import chain
+from logging import INFO
 from pathlib import Path
+from shutil import copyfile
 from typing import FrozenSet, Optional
 
+from coloredlogs import install
 from git import Repo
 from git.exc import InvalidGitRepositoryError
 from yaml import safe_load
@@ -33,3 +36,15 @@ def get_git_dir(path: Path) -> Optional[Path]:
             "Are you in one?"
         ) from e
     return Path(repository.git.rev_parse("--show-toplevel")).resolve()
+
+
+def copy_file_if_newer(original: Path, copy: Path) -> None:
+    if copy.exists() and copy.stat().st_mtime > original.stat().st_mtime:
+        return
+    else:
+        copy.parent.mkdir(parents=True, exist_ok=True)
+        copyfile(original, copy)
+
+
+def setup_logging(level: int = INFO) -> None:
+    install(level=level, fmt="%(asctime)s %(name)s %(message)s", datefmt="%H:%M:%S")
